==> cost-main-rpc-1.1.1-sources.jar: com/chinayanghe/tpm/rpc/constants/FormMethodUri.java <==
package com.chinayanghe.tpm.rpc.constants;

import java.util.HashMap;

/**
 * Created by wanggq on 2017/7/10.
 */
public class FormMethodUri {

    private FormMethodUri (){}

    private static final HashMap<String,String> uriMap = new HashMap<String, String>();

    static{
        uriMap.put(ActivityTypeEnum.activity211801.getCode()+FormTypeEnum.apply,"admin.consumerApply.updateApplyFormData");
        uriMap.put(ActivityTypeEnum.activity211801.getCode()+FormTypeEnum.regist,"admin.consumerRegistration.tempSave");
        uriMap.put(ActivityTypeEnum.activity211801.getCode()+FormTypeEnum.pay,"admin.consumerPay.tempSave");
        uriMap.put(ActivityTypeEnum.activity211801.getCode()+FormTypeEnum.reported,"admin.consumerReported.tempSave");
        /** 达标奖励 */
        uriMap.put(ActivityTypeEnum.activity211101.getCode()+FormTypeEnum.apply,"admin.welldoneApplyEdit.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity211101.getCode()+FormTypeEnum.regist,"admin.welldoneRegistEdit.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity211101.getCode()+FormTypeEnum.pay,"admin.welldonePayEdit.saveDataInfo");
        /**专卖店支持*/
        uriMap.put(ActivityTypeEnum.activity211501.getCode()+FormTypeEnum.apply,"admin.cost.exclusiveStore.updateApplyFormData");
        uriMap.put(ActivityTypeEnum.activity211501.getCode()+FormTypeEnum.regist,"admin.cost.exclusiveStore.updateRegistFormData");
        uriMap.put(ActivityTypeEnum.activity211501.getCode()+FormTypeEnum.pay,"admin.cost.exclusiveStore.updatePayFormData");
        
        uriMap.put(ActivityTypeEnum.activity211601.getCode()+FormTypeEnum.apply,"admin.normalPromotionApply.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity211601.getCode()+FormTypeEnum.regist,"admin.normalPromotionRegist.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity211601.getCode()+FormTypeEnum.pay,"admin.normalPromotionPay.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity211001.getCode()+FormTypeEnum.apply,"admin.personalTasking.saveOrUpdateTableInfo");
        uriMap.put(ActivityTypeEnum.activity211001.getCode()+FormTypeEnum.pay,"admin.PersonalReviewPay.savePersonalReviewApplyFormData");
        /*渠道劳务*/
        uriMap.put(ActivityTypeEnum.activity210401.getCode()+FormTypeEnum.apply,"admin.channelLabor.saveApplyFormData");
        uriMap.put(ActivityTypeEnum.activity210401.getCode()+FormTypeEnum.regist,"admin.channelLabor.saveRegisterFormData");
        uriMap.put(ActivityTypeEnum.activity210401.getCode()+FormTypeEnum.pay,"admin.channelLabor.savePayFormData");
        /*区域点上事件营销*/
        uriMap.put(ActivityTypeEnum.activity210301.getCode()+FormTypeEnum.apply,"admin.areaPointEvent.saveApplyFormData");
        uriMap.put(ActivityTypeEnum.activity210301.getCode()+FormTypeEnum.regist,"admin.areaPointEvent.saveRegisterFormData");
        uriMap.put(ActivityTypeEnum.activity210301.getCode()+FormTypeEnum.pay,"admin.areaPointEvent.savePayFormData");
        /** 单位赠酒 */
        uriMap.put(ActivityTypeEnum.activity211002.getCode()+FormTypeEnum.apply,"admin.companyGiftWineApply.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity211002.getCode()+FormTypeEnum.pay,"admin.companyGiftWinePay.saveDataInfo");
        /** 点上赞助捐赠 */
        uriMap.put(ActivityTypeEnum.activity210201.getCode()+FormTypeEnum.apply,"admin.areaPointApply.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210201.getCode()+FormTypeEnum.regist,"admin.areaPointRegist.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210201.getCode()+FormTypeEnum.reported,"admin.areaPointReported.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210201.getCode()+FormTypeEnum.pay,"admin.areaPointPay.saveDataInfo");
        /** 区域面上事件营销 */
        uriMap.put(ActivityTypeEnum.activity210302.getCode()+FormTypeEnum.apply,"admin.areaPlaneEventApply.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210302.getCode()+FormTypeEnum.apply,"admin.areaPlaneEventRegist.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210302.getCode()+FormTypeEnum.apply,"admin.areaPlaneEventPay.saveDataInfo");
        /** 门头牌 */
        uriMap.put(ActivityTypeEnum.activity210801.getCode()+FormTypeEnum.apply,"admin.doorplateApply.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210801.getCode()+FormTypeEnum.apply,"admin.doorplateRegist.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210801.getCode()+FormTypeEnum.apply,"admin.doorplatePay.saveDataInfo");
    }

    public static String get(String key){
        return uriMap.get(key);
    }

}

==> cost-main-rpc-1.1.4-sources.jar: com/chinayanghe/tpm/rpc/constants/FormMethodUri.java <==
package com.chinayanghe.tpm.rpc.constants;

import java.util.HashMap;

/**
 * Created by wanggq on 2017/7/10.
 */
public class FormMethodUri {

    private FormMethodUri (){}

    private static final HashMap<String,String> uriMap = new HashMap<String, String>();

    static{
        uriMap.put(ActivityTypeEnum.activity211801.getCode()+FormTypeEnum.apply,"admin.consumerApply.updateApplyFormData");
        uriMap.put(ActivityTypeEnum.activity211801.getCode()+FormTypeEnum.regist,"admin.consumerRegistration.tempSave");
        uriMap.put(ActivityTypeEnum.activity211801.getCode()+FormTypeEnum.pay,"admin.consumerPay.tempSave");
        uriMap.put(ActivityTypeEnum.activity211801.getCode()+FormTypeEnum.reported,"admin.consumerReported.tempSave");
        /** 达标奖励 */
        uriMap.put(ActivityTypeEnum.activity211101.getCode()+FormTypeEnum.apply,"admin.welldoneApplyEdit.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity211101.getCode()+FormTypeEnum.regist,"admin.welldoneRegistEdit.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity211101.getCode()+FormTypeEnum.pay,"admin.welldonePayEdit.saveDataInfo");
        /**专卖店支持*/
        uriMap.put(ActivityTypeEnum.activity211501.getCode()+FormTypeEnum.apply,"admin.cost.exclusiveStore.updateApplyFormData");
        uriMap.put(ActivityTypeEnum.activity211501.getCode()+FormTypeEnum.regist,"admin.cost.exclusiveStore.updateRegistFormData");
        uriMap.put(ActivityTypeEnum.activity211501.getCode()+FormTypeEnum.pay,"admin.cost.exclusiveStore.updatePayFormData");
        /** 常规促销品*/
        uriMap.put(ActivityTypeEnum.activity211601.getCode()+FormTypeEnum.apply,"admin.normalPromotionApply.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity211601.getCode()+FormTypeEnum.regist,"admin.normalPromotionRegist.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity211601.getCode()+FormTypeEnum.pay,"admin.normalPromotionPay.updateTempSave");
        /**个人品鉴*/
        uriMap.put(ActivityTypeEnum.activity211001.getCode()+FormTypeEnum.apply,"admin.personalTasking.saveOrUpdateTableInfo");
        uriMap.put(ActivityTypeEnum.activity211001.getCode()+FormTypeEnum.pay,"admin.PersonalReviewPay.savePersonalReviewApplyFormData");
        /*渠道劳务*/
        uriMap.put(ActivityTypeEnum.activity210401.getCode()+FormTypeEnum.apply,"admin.channelLabor.saveApplyFormData");
        uriMap.put(ActivityTypeEnum.activity210401.getCode()+FormTypeEnum.regist,"admin.channelLabor.saveRegisterFormData");
        uriMap.put(ActivityTypeEnum.activity210401.getCode()+FormTypeEnum.pay,"admin.channelLabor.savePayFormData");
        /*区域点上事件营销*/
        uriMap.put(ActivityTypeEnum.activity210301.getCode()+FormTypeEnum.apply,"admin.areaPointEvent.saveApplyFormData");
        uriMap.put(ActivityTypeEnum.activity210301.getCode()+FormTypeEnum.regist,"admin.areaPointEvent.saveRegisterFormData");
        uriMap.put(ActivityTypeEnum.activity210301.getCode()+FormTypeEnum.pay,"admin.areaPointEvent.savePayFormData");
        /** 单位赠酒 */
        uriMap.put(ActivityTypeEnum.activity211002.getCode()+FormTypeEnum.apply,"admin.companyGiftWineApply.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity211002.getCode()+FormTypeEnum.pay,"admin.companyGiftWinePay.saveDataInfo");
        /** 点上赞助捐赠 */
        uriMap.put(ActivityTypeEnum.activity210201.getCode()+FormTypeEnum.apply,"admin.areaPointApply.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210201.getCode()+FormTypeEnum.regist,"admin.areaPointRegist.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210201.getCode()+FormTypeEnum.reported,"admin.areaPointReported.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210201.getCode()+FormTypeEnum.pay,"admin.areaPointPay.saveDataInfo");
        /** 区域面上事件营销 */
        uriMap.put(ActivityTypeEnum.activity210302.getCode()+FormTypeEnum.apply,"admin.areaPlaneEventApply.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210302.getCode()+FormTypeEnum.regist,"admin.areaPlaneEventRegist.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210302.getCode()+FormTypeEnum.pay,"admin.areaPlaneEventPay.saveDataInfo");
        /** 门头牌 */
        uriMap.put(ActivityTypeEnum.activity210801.getCode()+FormTypeEnum.apply,"admin.doorplateApply.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210801.getCode()+FormTypeEnum.regist,"admin.doorplateRegist.saveDataInfo");
        uriMap.put(ActivityTypeEnum.activity210801.getCode()+FormTypeEnum.pay,"admin.doorplatePay.saveDataInfo");
        /** 渠道宣传费*/
        uriMap.put(ActivityTypeEnum.activity210902.getCode()+FormTypeEnum.apply,"admin.marketChannelApply.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity210902.getCode()+FormTypeEnum.regist,"admin.marketChannelRegist.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity210902.getCode()+FormTypeEnum.reported,"admin.marketChannelReported.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity210902.getCode()+FormTypeEnum.pay,"admin.marketChannelPay.updateTempSave");
        /** 酒店个性化*/
        uriMap.put(ActivityTypeEnum.activity211301.getCode()+FormTypeEnum.apply,"admin.hotelAwardApply.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity211301.getCode()+FormTypeEnum.regist,"admin.hotelAwardRegist.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity211301.getCode()+FormTypeEnum.pay,"admin.hotelAwardPay.updateTempSave");
        uriMap.put(ActivityTypeEnum.activity211301.getCode()+FormTypeEnum.pay,"admin.hotelAwardPayReal.updateTempSave");
        
        /**部队慰问*/
        uriMap.put(ActivityTypeEnum.activity211003.getCode()+FormTypeEnum.apply,"admin.troopCarpManage.updataTroopCareApply?type=1");
        uriMap.put(ActivityTypeEnum.activity211003.getCode()+FormTypeEnum.regist,"admin.troopCarpManage.updataTroopCareApply?type=3");
        uriMap.put(ActivityTypeEnum.activity211003.getCode()+FormTypeEnum.pay,"admin.troopCarpManage.updataTroopCareApply?type=5");
    }

    public static String get(String key){
        return uriMap.get(key);
    }

}
